@@ -14,11 +14,8 @@ class MetricsExporter:
     Wrapper for metrics exporting. Accepts raw dicts and appends them into the metrics file.
     """
 
-    def __init__(self, mem_store: bool = False):
-        if mem_store:
-            self.storage = MemStorage()
-        else:
-            self.storage = FileStorage(os.getenv("METRICS_PATH"))
+    def __init__(self, storage):
+        self.storage = storage
 
     def __enter__(self):
         return self
